@@ -1,9 +1,9 @@
 package List::AllUtils::Null;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-01'; # DATE
+our $DATE = '2021-07-05'; # DATE
 our $DIST = 'List-AllUtils-Null'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -80,7 +80,7 @@ List::AllUtils::Null - List subroutines that treat undef as contagious unknown,
 
 =head1 VERSION
 
-This document describes version 0.002 of List::AllUtils::Null (from Perl distribution List-AllUtils-Null), released on 2021-04-01.
+This document describes version 0.003 of List::AllUtils::Null (from Perl distribution List-AllUtils-Null), released on 2021-07-05.
 
 =head1 SYNOPSIS
 
@@ -122,7 +122,7 @@ Source repository is at L<https://github.com/perlancar/perl-List-AllUtils-Null>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-List-AllUtils-Null/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=List-AllUtils-Null>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -135,6 +135,8 @@ Your favorite SQL reference.
 L<List::Util> and friends (L<List::SomeUtils>, L<List::UtilsBy>,
 L<List::MoreUtils>, L<List::AllUtils>).
 
+L<List::AllUtils::ContainsNull>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
